@@ -435,6 +435,7 @@ class RSSHTControllerWindow(QMainWindow):
         if lock_mutex:
             locker = QMutexLocker(controllerp.get_mutex())
         
+        treeview = self._treeview
         header = self._treeview.header()
         sel_model = self._treeview.selectionModel()
         model = self._treeview_model
@@ -442,6 +443,9 @@ class RSSHTControllerWindow(QMainWindow):
         
         # Save state
         
+        vslider_pos = treeview.verticalScrollBar().sliderPosition()
+        hslider_pos = treeview.horizontalScrollBar().sliderPosition()
+        
         if sel_model.hasSelection():
             selected_agent_id = self._selected_data(self.AGENT_ID_COL)
         else:
@@ -654,6 +658,9 @@ class RSSHTControllerWindow(QMainWindow):
             sort_order = header.sortIndicatorOrder()
             model.sort(sort_section, sort_order)
         
+        treeview.verticalScrollBar().setSliderPosition(vslider_pos)
+        treeview.horizontalScrollBar().setSliderPosition(hslider_pos)
+        
     def _selected_data(self, col):
         sel_model = self._treeview.selectionModel()
         index = sel_model.selectedRows(col)[0]
